@@ -6,9 +6,11 @@ types: list[str] = [
     "AWS::ACMPCA::CertificateAuthority",
     "AWS::ACMPCA::CertificateAuthorityActivation",
     "AWS::ACMPCA::Permission",
+    "AWS::AIOps::InvestigationGroup",
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -72,6 +74,8 @@ types: list[str] = [
     "AWS::AppSync::SourceApiAssociation",
     "AWS::ApplicationAutoScaling::ScalableTarget",
     "AWS::ApplicationAutoScaling::ScalingPolicy",
+    "AWS::ApplicationSignals::Discovery",
+    "AWS::ApplicationSignals::ServiceLevelObjective",
     "AWS::Athena::DataCatalog",
     "AWS::Athena::NamedQuery",
     "AWS::Athena::PreparedStatement",
@@ -90,6 +94,7 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::CDK::Metadata",
     "AWS::CertificateManager::Certificate",
     "AWS::CloudFormation::CustomResource",
@@ -131,6 +136,16 @@ types: list[str] = [
     "AWS::CodeDeploy::DeploymentGroup",
     "AWS::CodePipeline::CustomActionType",
     "AWS::CodePipeline::Pipeline",
+    "AWS::Cognito::IdentityPool",
+    "AWS::Cognito::IdentityPoolPrincipalTag",
+    "AWS::Cognito::IdentityPoolRoleAttachment",
+    "AWS::Cognito::LogDeliveryConfiguration",
+    "AWS::Cognito::UserPool",
+    "AWS::Cognito::UserPoolClient",
+    "AWS::Cognito::UserPoolGroup",
+    "AWS::Cognito::UserPoolRiskConfigurationAttachment",
+    "AWS::Cognito::UserPoolUser",
+    "AWS::Cognito::UserPoolUserToGroupAttachment",
     "AWS::Config::AggregationAuthorization",
     "AWS::Config::ConfigRule",
     "AWS::Config::ConfigurationAggregator",
@@ -160,6 +175,10 @@ types: list[str] = [
     "AWS::DynamoDB::GlobalTable",
     "AWS::DynamoDB::Table",
     "AWS::EC2::CapacityReservation",
+    "AWS::EC2::ClientVpnAuthorizationRule",
+    "AWS::EC2::ClientVpnEndpoint",
+    "AWS::EC2::ClientVpnRoute",
+    "AWS::EC2::ClientVpnTargetNetworkAssociation",
     "AWS::EC2::CustomerGateway",
     "AWS::EC2::DHCPOptions",
     "AWS::EC2::EC2Fleet",
@@ -177,12 +196,18 @@ types: list[str] = [
     "AWS::EC2::IPAMResourceDiscoveryAssociation",
     "AWS::EC2::IPAMScope",
     "AWS::EC2::Instance",
+    "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::NatGateway",
     "AWS::EC2::NetworkAcl",
     "AWS::EC2::NetworkAclEntry",
+    "AWS::EC2::NetworkInsightsAccessScope",
+    "AWS::EC2::NetworkInsightsAccessScopeAnalysis",
+    "AWS::EC2::NetworkInsightsAnalysis",
+    "AWS::EC2::NetworkInsightsPath",
     "AWS::EC2::NetworkInterface",
     "AWS::EC2::NetworkInterfaceAttachment",
     "AWS::EC2::NetworkInterfacePermission",
@@ -194,6 +219,7 @@ types: list[str] = [
     "AWS::EC2::SecurityGroupEgress",
     "AWS::EC2::SecurityGroupIngress",
     "AWS::EC2::SecurityGroupVpcAssociation",
+    "AWS::EC2::SnapshotBlockPublicAccess",
     "AWS::EC2::SpotFleet",
     "AWS::EC2::Subnet",
     "AWS::EC2::SubnetCidrBlock",
@@ -205,6 +231,8 @@ types: list[str] = [
     "AWS::EC2::TrafficMirrorTarget",
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
+    "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -251,6 +279,7 @@ types: list[str] = [
     "AWS::EKS::AccessEntry",
     "AWS::EKS::Addon",
     "AWS::EKS::Cluster",
+    "AWS::EKS::FargateProfile",
     "AWS::EKS::IdentityProviderConfig",
     "AWS::EKS::Nodegroup",
     "AWS::EKS::PodIdentityAssociation",
@@ -287,6 +316,7 @@ types: list[str] = [
     "AWS::FMS::NotificationChannel",
     "AWS::FMS::Policy",
     "AWS::FMS::ResourceSet",
+    "AWS::FSx::DataRepositoryAssociation",
     "AWS::FSx::FileSystem",
     "AWS::FSx::Snapshot",
     "AWS::FSx::StorageVirtualMachine",
@@ -408,6 +438,11 @@ types: list[str] = [
     "AWS::Organizations::OrganizationalUnit",
     "AWS::Organizations::Policy",
     "AWS::Organizations::ResourcePolicy",
+    "AWS::PCAConnectorAD::Connector",
+    "AWS::PCAConnectorAD::DirectoryRegistration",
+    "AWS::PCAConnectorAD::ServicePrincipalName",
+    "AWS::PCAConnectorAD::Template",
+    "AWS::PCAConnectorAD::TemplateGroupAccessControlEntry",
     "AWS::RAM::Permission",
     "AWS::RAM::ResourceShare",
     "AWS::RDS::DBCluster",
@@ -423,6 +458,7 @@ types: list[str] = [
     "AWS::RDS::EventSubscription",
     "AWS::RDS::GlobalCluster",
     "AWS::RDS::OptionGroup",
+    "AWS::RUM::AppMonitor",
     "AWS::Redshift::Cluster",
     "AWS::Redshift::ClusterParameterGroup",
     "AWS::Redshift::ClusterSecurityGroup",
@@ -434,6 +470,7 @@ types: list[str] = [
     "AWS::Redshift::Integration",
     "AWS::Redshift::ScheduledAction",
     "AWS::RedshiftServerless::Namespace",
+    "AWS::RedshiftServerless::Snapshot",
     "AWS::RedshiftServerless::Workgroup",
     "AWS::ResourceExplorer2::DefaultViewAssociation",
     "AWS::ResourceExplorer2::Index",
@@ -464,6 +501,11 @@ types: list[str] = [
     "AWS::S3::BucketPolicy",
     "AWS::S3ObjectLambda::AccessPoint",
     "AWS::S3ObjectLambda::AccessPointPolicy",
+    "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
+    "AWS::S3Tables::TableBucket",
+    "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
     "AWS::SNS::Subscription",
     "AWS::SNS::Topic",
@@ -480,10 +522,14 @@ types: list[str] = [
     "AWS::SSM::Parameter",
     "AWS::SSM::PatchBaseline",
     "AWS::SSM::ResourceDataSync",
+    "AWS::SageMaker::MlflowTrackingServer",
     "AWS::SageMaker::ModelCard",
     "AWS::SageMaker::ModelPackage",
     "AWS::SageMaker::ModelPackageGroup",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
+    "AWS::Scheduler::Schedule",
+    "AWS::Scheduler::ScheduleGroup",
     "AWS::SecretsManager::ResourcePolicy",
     "AWS::SecretsManager::RotationSchedule",
     "AWS::SecretsManager::Secret",
@@ -506,6 +552,13 @@ types: list[str] = [
     "AWS::StepFunctions::StateMachineAlias",
     "AWS::StepFunctions::StateMachineVersion",
     "AWS::Synthetics::Canary",
+    "AWS::Transfer::Agreement",
+    "AWS::Transfer::Certificate",
+    "AWS::Transfer::Connector",
+    "AWS::Transfer::Profile",
+    "AWS::Transfer::Server",
+    "AWS::Transfer::User",
+    "AWS::Transfer::Workflow",
     "AWS::WAF::ByteMatchSet",
     "AWS::WAF::IPSet",
     "AWS::WAF::Rule",
@@ -534,8 +587,10 @@ cached: list[str] = [
     "aws-acmpca-certificateauthority.json",
     "aws-acmpca-certificateauthorityactivation.json",
     "aws-acmpca-permission.json",
+    "aws-aiops-investigationgroup.json",
     "aws-amazonmq-broker.json",
     "aws-amazonmq-configuration.json",
+    "aws-amazonmq-configurationassociation.json",
     "aws-apigateway-account.json",
     "aws-apigateway-apikey.json",
     "aws-apigateway-authorizer.json",
@@ -551,7 +606,6 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -562,10 +616,11 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
-    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
+    "aws-applicationsignals-discovery.json",
+    "aws-applicationsignals-servicelevelobjective.json",
     "aws-appsync-api.json",
     "aws-appsync-apicache.json",
     "aws-appsync-apikey.json",
@@ -597,8 +652,8 @@ cached: list[str] = [
     "aws-batch-computeenvironment.json",
     "aws-batch-consumableresource.json",
     "aws-batch-jobdefinition.json",
-    "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-certificatemanager-certificate.json",
     "aws-cloudformation-customresource.json",
     "aws-cloudformation-hookdefaultversion.json",
@@ -629,9 +684,20 @@ cached: list[str] = [
     "aws-cloudwatch-alarm.json",
     "aws-cloudwatch-anomalydetector.json",
     "aws-cloudwatch-compositealarm.json",
+    "aws-cloudwatch-dashboard.json",
     "aws-cloudwatch-insightrule.json",
     "aws-cloudwatch-metricstream.json",
     "aws-codedeploy-deploymentgroup.json",
+    "aws-cognito-identitypool.json",
+    "aws-cognito-identitypoolprincipaltag.json",
+    "aws-cognito-identitypoolroleattachment.json",
+    "aws-cognito-logdeliveryconfiguration.json",
+    "aws-cognito-userpool.json",
+    "aws-cognito-userpoolclient.json",
+    "aws-cognito-userpoolgroup.json",
+    "aws-cognito-userpoolriskconfigurationattachment.json",
+    "aws-cognito-userpooluser.json",
+    "aws-cognito-userpoolusertogroupattachment.json",
     "aws-config-aggregationauthorization.json",
     "aws-config-configrule.json",
     "aws-config-configurationaggregator.json",
@@ -655,16 +721,20 @@ cached: list[str] = [
     "aws-datasync-locationsmb.json",
     "aws-datasync-task.json",
     "aws-dlm-lifecyclepolicy.json",
-    "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
+    "aws-ec2-clientvpnendpoint.json",
+    "aws-ec2-clientvpnroute.json",
+    "aws-ec2-clientvpntargetnetworkassociation.json",
     "aws-ec2-customergateway.json",
     "aws-ec2-dhcpoptions.json",
+    "aws-ec2-ec2fleet.json",
+    "aws-ec2-egressonlyinternetgateway.json",
     "aws-ec2-eip.json",
     "aws-ec2-eipassociation.json",
     "aws-ec2-flowlog.json",
     "aws-ec2-gatewayroutetableassociation.json",
     "aws-ec2-instance.json",
+    "aws-ec2-instanceconnectendpoint.json",
     "aws-ec2-internetgateway.json",
     "aws-ec2-ipam.json",
     "aws-ec2-ipamallocation.json",
@@ -678,6 +748,10 @@ cached: list[str] = [
     "aws-ec2-natgateway.json",
     "aws-ec2-networkacl.json",
     "aws-ec2-networkaclentry.json",
+    "aws-ec2-networkinsightsaccessscope.json",
+    "aws-ec2-networkinsightsaccessscopeanalysis.json",
+    "aws-ec2-networkinsightsanalysis.json",
+    "aws-ec2-networkinsightspath.json",
     "aws-ec2-networkinterface.json",
     "aws-ec2-networkinterfaceattachment.json",
     "aws-ec2-placementgroup.json",
@@ -688,15 +762,20 @@ cached: list[str] = [
     "aws-ec2-securitygroupegress.json",
     "aws-ec2-securitygroupingress.json",
     "aws-ec2-securitygroupvpcassociation.json",
+    "aws-ec2-snapshotblockpublicaccess.json",
     "aws-ec2-spotfleet.json",
     "aws-ec2-subnet.json",
     "aws-ec2-subnetcidrblock.json",
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
+    "aws-ec2-trafficmirrorfilter.json",
     "aws-ec2-trafficmirrorfilterrule.json",
+    "aws-ec2-trafficmirrorsession.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
+    "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -731,10 +810,10 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
-    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
+    "aws-ecs-taskdefinition.json",
     "aws-ecs-taskset.json",
     "aws-efs-accesspoint.json",
     "aws-efs-filesystem.json",
@@ -742,19 +821,21 @@ cached: list[str] = [
     "aws-eks-accessentry.json",
     "aws-eks-addon.json",
     "aws-eks-cluster.json",
+    "aws-eks-fargateprofile.json",
     "aws-eks-identityproviderconfig.json",
     "aws-eks-nodegroup.json",
     "aws-eks-podidentityassociation.json",
     "aws-elasticache-cachecluster.json",
     "aws-elasticache-globalreplicationgroup.json",
+    "aws-elasticache-parametergroup.json",
     "aws-elasticache-replicationgroup.json",
     "aws-elasticache-securitygroup.json",
     "aws-elasticache-securitygroupingress.json",
     "aws-elasticache-serverlesscache.json",
+    "aws-elasticache-subnetgroup.json",
     "aws-elasticache-user.json",
     "aws-elasticache-usergroup.json",
     "aws-elasticloadbalancing-loadbalancer.json",
-    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -772,6 +853,7 @@ cached: list[str] = [
     "aws-fms-notificationchannel.json",
     "aws-fms-policy.json",
     "aws-fms-resourceset.json",
+    "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
     "aws-fsx-snapshot.json",
     "aws-fsx-storagevirtualmachine.json",
@@ -824,9 +906,10 @@ cached: list[str] = [
     "aws-iot-thingprincipalattachment.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
+    "aws-kinesis-streamconsumer.json",
     "aws-kinesisanalyticsv2-application.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kms-alias.json",
+    "aws-kms-key.json",
     "aws-kms-replicakey.json",
     "aws-lakeformation-datacellsfilter.json",
     "aws-lakeformation-datalakesettings.json",
@@ -846,8 +929,6 @@ cached: list[str] = [
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
-    "aws-logs-destination.json",
-    "aws-logs-loggroup.json",
     "aws-logs-logstream.json",
     "aws-logs-metricfilter.json",
     "aws-logs-querydefinition.json",
@@ -867,7 +948,6 @@ cached: list[str] = [
     "aws-networkfirewall-vpcendpointassociation.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
-    "aws-opensearchservice-domain.json",
     "aws-opsworks-app.json",
     "aws-opsworks-elasticloadbalancerattachment.json",
     "aws-opsworks-userprofile.json",
@@ -877,6 +957,11 @@ cached: list[str] = [
     "aws-organizations-organizationalunit.json",
     "aws-organizations-policy.json",
     "aws-organizations-resourcepolicy.json",
+    "aws-pcaconnectorad-connector.json",
+    "aws-pcaconnectorad-directoryregistration.json",
+    "aws-pcaconnectorad-serviceprincipalname.json",
+    "aws-pcaconnectorad-template.json",
+    "aws-pcaconnectorad-templategroupaccesscontrolentry.json",
     "aws-ram-permission.json",
     "aws-ram-resourceshare.json",
     "aws-rds-dbcluster.json",
@@ -892,17 +977,15 @@ cached: list[str] = [
     "aws-rds-eventsubscription.json",
     "aws-rds-globalcluster.json",
     "aws-rds-optiongroup.json",
-    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
-    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
-    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-resourceexplorer2-defaultviewassociation.json",
     "aws-resourceexplorer2-index.json",
@@ -912,7 +995,6 @@ cached: list[str] = [
     "aws-rolesanywhere-profile.json",
     "aws-rolesanywhere-trustanchor.json",
     "aws-route53-cidrcollection.json",
-    "aws-route53-hostedzone.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
     "aws-route53profiles-profile.json",
@@ -921,21 +1003,28 @@ cached: list[str] = [
     "aws-route53resolver-firewalldomainlist.json",
     "aws-route53resolver-firewallrulegroup.json",
     "aws-route53resolver-firewallrulegroupassociation.json",
-    "aws-route53resolver-resolverconfig.json",
     "aws-route53resolver-resolverendpoint.json",
     "aws-route53resolver-resolverqueryloggingconfig.json",
     "aws-route53resolver-resolverqueryloggingconfigassociation.json",
-    "aws-route53resolver-resolverrule.json",
-    "aws-route53resolver-resolverruleassociation.json",
+    "aws-rum-appmonitor.json",
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
     "aws-s3objectlambda-accesspoint.json",
     "aws-s3objectlambda-accesspointpolicy.json",
+    "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
+    "aws-s3tables-tablebucket.json",
+    "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
+    "aws-sagemaker-mlflowtrackingserver.json",
     "aws-sagemaker-modelcard.json",
     "aws-sagemaker-modelpackage.json",
     "aws-sagemaker-modelpackagegroup.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
+    "aws-scheduler-schedule.json",
+    "aws-scheduler-schedulegroup.json",
     "aws-sdb-domain.json",
     "aws-secretsmanager-resourcepolicy.json",
     "aws-secretsmanager-rotationschedule.json",
@@ -974,6 +1063,13 @@ cached: list[str] = [
     "aws-stepfunctions-statemachinealias.json",
     "aws-stepfunctions-statemachineversion.json",
     "aws-synthetics-canary.json",
+    "aws-transfer-agreement.json",
+    "aws-transfer-certificate.json",
+    "aws-transfer-connector.json",
+    "aws-transfer-profile.json",
+    "aws-transfer-server.json",
+    "aws-transfer-user.json",
+    "aws-transfer-workflow.json",
     "aws-waf-bytematchset.json",
     "aws-waf-sqlinjectionmatchset.json",
     "aws-wafv2-ipset.json",
