@@ -10,6 +10,7 @@ types: list[str] = [
     "AWS::APS::RuleGroupsNamespace",
     "AWS::APS::Scraper",
     "AWS::APS::Workspace",
+    "AWS::ARCRegionSwitch::Plan",
     "AWS::ARCZonalShift::AutoshiftObserverNotificationStatus",
     "AWS::ARCZonalShift::ZonalAutoshiftConfiguration",
     "AWS::AccessAnalyzer::Analyzer",
@@ -142,6 +143,7 @@ types: list[str] = [
     "AWS::Batch::JobDefinition",
     "AWS::Batch::JobQueue",
     "AWS::Batch::SchedulingPolicy",
+    "AWS::Batch::ServiceEnvironment",
     "AWS::Bedrock::Agent",
     "AWS::Bedrock::AgentAlias",
     "AWS::Bedrock::ApplicationInferenceProfile",
@@ -383,6 +385,7 @@ types: list[str] = [
     "AWS::EC2::Instance",
     "AWS::EC2::InstanceConnectEndpoint",
     "AWS::EC2::InternetGateway",
+    "AWS::EC2::IpPoolRouteTableAssociation",
     "AWS::EC2::KeyPair",
     "AWS::EC2::LaunchTemplate",
     "AWS::EC2::LocalGatewayRoute",
@@ -426,6 +429,7 @@ types: list[str] = [
     "AWS::EC2::TransitGateway",
     "AWS::EC2::TransitGatewayAttachment",
     "AWS::EC2::TransitGatewayConnect",
+    "AWS::EC2::TransitGatewayConnectPeer",
     "AWS::EC2::TransitGatewayMulticastDomain",
     "AWS::EC2::TransitGatewayMulticastDomainAssociation",
     "AWS::EC2::TransitGatewayMulticastGroupMember",
@@ -855,6 +859,7 @@ types: list[str] = [
     "AWS::NetworkFirewall::LoggingConfiguration",
     "AWS::NetworkFirewall::RuleGroup",
     "AWS::NetworkFirewall::TLSInspectionConfiguration",
+    "AWS::NetworkFirewall::VpcEndpointAssociation",
     "AWS::NetworkManager::ConnectAttachment",
     "AWS::NetworkManager::ConnectPeer",
     "AWS::NetworkManager::CoreNetwork",
@@ -874,6 +879,8 @@ types: list[str] = [
     "AWS::OSIS::Pipeline",
     "AWS::Oam::Link",
     "AWS::Oam::Sink",
+    "AWS::ObservabilityAdmin::OrganizationTelemetryRule",
+    "AWS::ObservabilityAdmin::TelemetryRule",
     "AWS::OpenSearchServerless::AccessPolicy",
     "AWS::OpenSearchServerless::Collection",
     "AWS::OpenSearchServerless::Index",
@@ -890,7 +897,6 @@ types: list[str] = [
     "AWS::OpsWorks::Stack",
     "AWS::OpsWorks::UserProfile",
     "AWS::OpsWorks::Volume",
-    "AWS::OpsWorksCM::Server",
     "AWS::Organizations::Account",
     "AWS::Organizations::Organization",
     "AWS::Organizations::OrganizationalUnit",
@@ -1027,8 +1033,10 @@ types: list[str] = [
     "AWS::S3Outposts::BucketPolicy",
     "AWS::S3Outposts::Endpoint",
     "AWS::S3Tables::Namespace",
+    "AWS::S3Tables::Table",
     "AWS::S3Tables::TableBucket",
     "AWS::S3Tables::TableBucketPolicy",
+    "AWS::S3Tables::TablePolicy",
     "AWS::SDB::Domain",
     "AWS::SES::ConfigurationSet",
     "AWS::SES::ConfigurationSetEventDestination",
@@ -1106,6 +1114,7 @@ types: list[str] = [
     "AWS::SageMaker::NotebookInstanceLifecycleConfig",
     "AWS::SageMaker::PartnerApp",
     "AWS::SageMaker::Pipeline",
+    "AWS::SageMaker::ProcessingJob",
     "AWS::SageMaker::Project",
     "AWS::SageMaker::Space",
     "AWS::SageMaker::StudioLifecycleConfig",
@@ -1275,7 +1284,6 @@ cached: list[str] = [
     "aws-apigateway-model.json",
     "aws-apigateway-requestvalidator.json",
     "aws-apigateway-resource.json",
-    "aws-apigateway-restapi.json",
     "aws-apigateway-stage.json",
     "aws-apigateway-usageplan.json",
     "aws-apigateway-usageplankey.json",
@@ -1298,7 +1306,6 @@ cached: list[str] = [
     "aws-appconfig-configurationprofile.json",
     "aws-appconfig-deployment.json",
     "aws-appconfig-deploymentstrategy.json",
-    "aws-appconfig-environment.json",
     "aws-appconfig-extension.json",
     "aws-appconfig-extensionassociation.json",
     "aws-appconfig-hostedconfigurationversion.json",
@@ -1348,6 +1355,7 @@ cached: list[str] = [
     "aws-aps-rulegroupsnamespace.json",
     "aws-aps-scraper.json",
     "aws-aps-workspace.json",
+    "aws-arcregionswitch-plan.json",
     "aws-arczonalshift-autoshiftobservernotificationstatus.json",
     "aws-arczonalshift-zonalautoshiftconfiguration.json",
     "aws-athena-capacityreservation.json",
@@ -1381,6 +1389,7 @@ cached: list[str] = [
     "aws-batch-jobdefinition.json",
     "aws-batch-jobqueue.json",
     "aws-batch-schedulingpolicy.json",
+    "aws-batch-serviceenvironment.json",
     "aws-bedrock-agent.json",
     "aws-bedrock-agentalias.json",
     "aws-bedrock-applicationinferenceprofile.json",
@@ -1397,6 +1406,7 @@ cached: list[str] = [
     "aws-budgets-budget.json",
     "aws-budgets-budgetsaction.json",
     "aws-cassandra-keyspace.json",
+    "aws-cassandra-table.json",
     "aws-cassandra-type.json",
     "aws-ce-anomalymonitor.json",
     "aws-ce-anomalysubscription.json",
@@ -1407,7 +1417,6 @@ cached: list[str] = [
     "aws-chatbot-slackchannelconfiguration.json",
     "aws-cleanrooms-analysistemplate.json",
     "aws-cleanrooms-collaboration.json",
-    "aws-cleanrooms-configuredtable.json",
     "aws-cleanrooms-configuredtableassociation.json",
     "aws-cleanrooms-idmappingtable.json",
     "aws-cleanrooms-idnamespaceassociation.json",
@@ -1581,14 +1590,13 @@ cached: list[str] = [
     "aws-dms-replicationinstance.json",
     "aws-dms-replicationsubnetgroup.json",
     "aws-dms-replicationtask.json",
+    "aws-docdb-dbcluster.json",
     "aws-docdb-dbclusterparametergroup.json",
     "aws-docdb-dbinstance.json",
     "aws-docdb-dbsubnetgroup.json",
     "aws-docdb-eventsubscription.json",
     "aws-docdbelastic-cluster.json",
     "aws-dsql-cluster.json",
-    "aws-dynamodb-globaltable.json",
-    "aws-dynamodb-table.json",
     "aws-ec2-capacityreservation.json",
     "aws-ec2-capacityreservationfleet.json",
     "aws-ec2-carriergateway.json",
@@ -1653,11 +1661,13 @@ cached: list[str] = [
     "aws-ec2-subnetnetworkaclassociation.json",
     "aws-ec2-subnetroutetableassociation.json",
     "aws-ec2-trafficmirrorfilter.json",
+    "aws-ec2-trafficmirrorfilterrule.json",
     "aws-ec2-trafficmirrorsession.json",
     "aws-ec2-trafficmirrortarget.json",
     "aws-ec2-transitgateway.json",
     "aws-ec2-transitgatewayattachment.json",
     "aws-ec2-transitgatewayconnect.json",
+    "aws-ec2-transitgatewayconnectpeer.json",
     "aws-ec2-transitgatewaymulticastdomain.json",
     "aws-ec2-transitgatewaymulticastdomainassociation.json",
     "aws-ec2-transitgatewaymulticastgroupmember.json",
@@ -1696,7 +1706,6 @@ cached: list[str] = [
     "aws-ecr-repository.json",
     "aws-ecr-repositorycreationtemplate.json",
     "aws-ecs-capacityprovider.json",
-    "aws-ecs-cluster.json",
     "aws-ecs-clustercapacityproviderassociations.json",
     "aws-ecs-primarytaskset.json",
     "aws-ecs-service.json",
@@ -1727,7 +1736,6 @@ cached: list[str] = [
     "aws-elasticbeanstalk-configurationtemplate.json",
     "aws-elasticbeanstalk-environment.json",
     "aws-elasticloadbalancing-loadbalancer.json",
-    "aws-elasticloadbalancingv2-listener.json",
     "aws-elasticloadbalancingv2-listenercertificate.json",
     "aws-elasticloadbalancingv2-listenerrule.json",
     "aws-elasticloadbalancingv2-loadbalancer.json",
@@ -1744,6 +1752,7 @@ cached: list[str] = [
     "aws-emr-studiosessionmapping.json",
     "aws-emr-walworkspace.json",
     "aws-emrcontainers-virtualcluster.json",
+    "aws-emrserverless-application.json",
     "aws-entityresolution-idmappingworkflow.json",
     "aws-entityresolution-idnamespace.json",
     "aws-entityresolution-matchingworkflow.json",
@@ -1775,12 +1784,8 @@ cached: list[str] = [
     "aws-forecast-dataset.json",
     "aws-forecast-datasetgroup.json",
     "aws-frauddetector-detector.json",
-    "aws-frauddetector-entitytype.json",
     "aws-frauddetector-eventtype.json",
-    "aws-frauddetector-label.json",
     "aws-frauddetector-list.json",
-    "aws-frauddetector-outcome.json",
-    "aws-frauddetector-variable.json",
     "aws-fsx-datarepositoryassociation.json",
     "aws-fsx-filesystem.json",
     "aws-fsx-s3accesspointattachment.json",
@@ -1933,7 +1938,6 @@ cached: list[str] = [
     "aws-kafkaconnect-workerconfiguration.json",
     "aws-kendra-datasource.json",
     "aws-kendra-faq.json",
-    "aws-kendra-index.json",
     "aws-kendraranking-executionplan.json",
     "aws-kinesis-resourcepolicy.json",
     "aws-kinesis-stream.json",
@@ -1945,7 +1949,6 @@ cached: list[str] = [
     "aws-kinesisanalyticsv2-applicationcloudwatchloggingoption.json",
     "aws-kinesisanalyticsv2-applicationoutput.json",
     "aws-kinesisanalyticsv2-applicationreferencedatasource.json",
-    "aws-kinesisfirehose-deliverystream.json",
     "aws-kinesisvideo-signalingchannel.json",
     "aws-kinesisvideo-stream.json",
     "aws-kms-alias.json",
@@ -1989,7 +1992,6 @@ cached: list[str] = [
     "aws-location-routecalculator.json",
     "aws-location-tracker.json",
     "aws-location-trackerconsumer.json",
-    "aws-logs-accountpolicy.json",
     "aws-logs-delivery.json",
     "aws-logs-deliverydestination.json",
     "aws-logs-deliverysource.json",
@@ -2073,13 +2075,14 @@ cached: list[str] = [
     "aws-neptune-dbinstance.json",
     "aws-neptune-dbparametergroup.json",
     "aws-neptune-dbsubnetgroup.json",
-    "aws-neptune-eventsubscription.json",
     "aws-neptunegraph-graph.json",
     "aws-neptunegraph-privategraphendpoint.json",
     "aws-networkfirewall-firewall.json",
     "aws-networkfirewall-firewallpolicy.json",
+    "aws-networkfirewall-loggingconfiguration.json",
     "aws-networkfirewall-rulegroup.json",
     "aws-networkfirewall-tlsinspectionconfiguration.json",
+    "aws-networkfirewall-vpcendpointassociation.json",
     "aws-networkmanager-connectattachment.json",
     "aws-networkmanager-connectpeer.json",
     "aws-networkmanager-corenetwork.json",
@@ -2097,6 +2100,8 @@ cached: list[str] = [
     "aws-networkmanager-vpcattachment.json",
     "aws-oam-link.json",
     "aws-oam-sink.json",
+    "aws-observabilityadmin-organizationtelemetryrule.json",
+    "aws-observabilityadmin-telemetryrule.json",
     "aws-opensearchserverless-accesspolicy.json",
     "aws-opensearchserverless-collection.json",
     "aws-opensearchserverless-index.json",
@@ -2113,7 +2118,6 @@ cached: list[str] = [
     "aws-opsworks-stack.json",
     "aws-opsworks-userprofile.json",
     "aws-opsworks-volume.json",
-    "aws-opsworkscm-server.json",
     "aws-organizations-account.json",
     "aws-organizations-organization.json",
     "aws-organizations-organizationalunit.json",
@@ -2173,17 +2177,15 @@ cached: list[str] = [
     "aws-rds-globalcluster.json",
     "aws-rds-integration.json",
     "aws-rds-optiongroup.json",
-    "aws-redshift-cluster.json",
     "aws-redshift-clusterparametergroup.json",
     "aws-redshift-clustersecuritygroup.json",
     "aws-redshift-clustersecuritygroupingress.json",
     "aws-redshift-clustersubnetgroup.json",
-    "aws-redshift-endpointaccess.json",
     "aws-redshift-endpointauthorization.json",
     "aws-redshift-eventsubscription.json",
     "aws-redshift-integration.json",
-    "aws-redshift-scheduledaction.json",
     "aws-redshiftserverless-namespace.json",
+    "aws-redshiftserverless-snapshot.json",
     "aws-redshiftserverless-workgroup.json",
     "aws-refactorspaces-application.json",
     "aws-refactorspaces-environment.json",
@@ -2211,7 +2213,6 @@ cached: list[str] = [
     "aws-route53-cidrcollection.json",
     "aws-route53-dnssec.json",
     "aws-route53-healthcheck.json",
-    "aws-route53-hostedzone.json",
     "aws-route53-keysigningkey.json",
     "aws-route53-recordset.json",
     "aws-route53-recordsetgroup.json",
@@ -2233,9 +2234,7 @@ cached: list[str] = [
     "aws-s3-accesspoint.json",
     "aws-s3-bucket.json",
     "aws-s3-bucketpolicy.json",
-    "aws-s3-multiregionaccesspoint.json",
     "aws-s3-multiregionaccesspointpolicy.json",
-    "aws-s3-storagelens.json",
     "aws-s3-storagelensgroup.json",
     "aws-s3express-accesspoint.json",
     "aws-s3express-bucketpolicy.json",
@@ -2247,8 +2246,10 @@ cached: list[str] = [
     "aws-s3outposts-bucketpolicy.json",
     "aws-s3outposts-endpoint.json",
     "aws-s3tables-namespace.json",
+    "aws-s3tables-table.json",
     "aws-s3tables-tablebucket.json",
     "aws-s3tables-tablebucketpolicy.json",
+    "aws-s3tables-tablepolicy.json",
     "aws-sagemaker-app.json",
     "aws-sagemaker-appimageconfig.json",
     "aws-sagemaker-cluster.json",
@@ -2276,6 +2277,7 @@ cached: list[str] = [
     "aws-sagemaker-notebookinstancelifecycleconfig.json",
     "aws-sagemaker-partnerapp.json",
     "aws-sagemaker-pipeline.json",
+    "aws-sagemaker-processingjob.json",
     "aws-sagemaker-project.json",
     "aws-sagemaker-space.json",
     "aws-sagemaker-studiolifecycleconfig.json",
@@ -2393,7 +2395,6 @@ cached: list[str] = [
     "aws-supportapp-accountalias.json",
     "aws-supportapp-slackchannelconfiguration.json",
     "aws-supportapp-slackworkspaceconfiguration.json",
-    "aws-synthetics-canary.json",
     "aws-synthetics-group.json",
     "aws-systemsmanagersap-application.json",
     "aws-timestream-database.json",
